==> huaweicloudsdkdevstar-3.0.46-py2.py3-none-any.whl: huaweicloudsdkdevstar/v1/model/show_template_file_request.py <==
# coding: utf-8

import pprint
import re

import six





class ShowTemplateFileRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'template_id': 'str',
        'file_path': 'str',
        'type': 'str'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'template_id': 'template_id',
        'file_path': 'file_path',
        'type': 'type'
    }

    def __init__(self, x_language=None, template_id=None, file_path=None, type=None):
        """ShowTemplateFileRequest - a model defined in huaweicloud sdk"""
        
        

        self._x_language = None
        self._template_id = None
        self._file_path = None
        self._type = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.template_id = template_id
        self.file_path = file_path
        if type is not None:
            self.type = type

    @property
    def x_language(self):
        """Gets the x_language of this ShowTemplateFileRequest.

        语言类型，缺省值为“zh-cn”。  枚举值： - zh-cn：中文 - en-us：英文 

        :return: The x_language of this ShowTemplateFileRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this ShowTemplateFileRequest.

        语言类型，缺省值为“zh-cn”。  枚举值： - zh-cn：中文 - en-us：英文 

        :param x_language: The x_language of this ShowTemplateFileRequest.
        :type: str
        """
        self._x_language = x_language

    @property
    def template_id(self):
        """Gets the template_id of this ShowTemplateFileRequest.

        模板ID，通过查询模板列表接口可获取相应的模板ID。

        :return: The template_id of this ShowTemplateFileRequest.
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this ShowTemplateFileRequest.

        模板ID，通过查询模板列表接口可获取相应的模板ID。

        :param template_id: The template_id of this ShowTemplateFileRequest.
        :type: str
        """
        self._template_id = template_id

    @property
    def file_path(self):
        """Gets the file_path of this ShowTemplateFileRequest.

        文件相对路径，基于当前根目录的相对文件路径，例如获取HELP.md文件内容，则文件相对路径为“template-resources/file/HELP.md”。

        :return: The file_path of this ShowTemplateFileRequest.
        :rtype: str
        """
        return self._file_path

    @file_path.setter
    def file_path(self, file_path):
        """Sets the file_path of this ShowTemplateFileRequest.

        文件相对路径，基于当前根目录的相对文件路径，例如获取HELP.md文件内容，则文件相对路径为“template-resources/file/HELP.md”。

        :param file_path: The file_path of this ShowTemplateFileRequest.
        :type: str
        """
        self._file_path = file_path

    @property
    def type(self):
        """Gets the type of this ShowTemplateFileRequest.

        读取文件来源，缺省值为“source-pachage”。  枚举值： - source-package: 源文件压缩包 - introduction: 说明文件 

        :return: The type of this ShowTemplateFileRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ShowTemplateFileRequest.

        读取文件来源，缺省值为“source-pachage”。  枚举值： - source-package: 源文件压缩包 - introduction: 说明文件 

        :param type: The type of this ShowTemplateFileRequest.
        :type: str
        """
        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowTemplateFileRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdevstar-3.0.51-py2.py3-none-any.whl: huaweicloudsdkdevstar/v1/model/show_template_file_request.py <==
# coding: utf-8

import re
import six





class ShowTemplateFileRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'template_id': 'str',
        'file_path': 'str',
        'type': 'str'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'template_id': 'template_id',
        'file_path': 'file_path',
        'type': 'type'
    }

    def __init__(self, x_language=None, template_id=None, file_path=None, type=None):
        """ShowTemplateFileRequest - a model defined in huaweicloud sdk"""
        
        

        self._x_language = None
        self._template_id = None
        self._file_path = None
        self._type = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.template_id = template_id
        self.file_path = file_path
        if type is not None:
            self.type = type

    @property
    def x_language(self):
        """Gets the x_language of this ShowTemplateFileRequest.

        语言类型，缺省值为“zh-cn”。  枚举值： - zh-cn：中文 - en-us：英文 

        :return: The x_language of this ShowTemplateFileRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this ShowTemplateFileRequest.

        语言类型，缺省值为“zh-cn”。  枚举值： - zh-cn：中文 - en-us：英文 

        :param x_language: The x_language of this ShowTemplateFileRequest.
        :type: str
        """
        self._x_language = x_language

    @property
    def template_id(self):
        """Gets the template_id of this ShowTemplateFileRequest.

        模板ID，通过查询模板列表接口可获取相应的模板ID。

        :return: The template_id of this ShowTemplateFileRequest.
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this ShowTemplateFileRequest.

        模板ID，通过查询模板列表接口可获取相应的模板ID。

        :param template_id: The template_id of this ShowTemplateFileRequest.
        :type: str
        """
        self._template_id = template_id

    @property
    def file_path(self):
        """Gets the file_path of this ShowTemplateFileRequest.

        文件相对路径，基于当前根目录的相对文件路径，例如获取HELP.md文件内容，则文件相对路径为“template-resources/file/HELP.md”。

        :return: The file_path of this ShowTemplateFileRequest.
        :rtype: str
        """
        return self._file_path

    @file_path.setter
    def file_path(self, file_path):
        """Sets the file_path of this ShowTemplateFileRequest.

        文件相对路径，基于当前根目录的相对文件路径，例如获取HELP.md文件内容，则文件相对路径为“template-resources/file/HELP.md”。

        :param file_path: The file_path of this ShowTemplateFileRequest.
        :type: str
        """
        self._file_path = file_path

    @property
    def type(self):
        """Gets the type of this ShowTemplateFileRequest.

        读取文件来源，缺省值为“source-pachage”。  枚举值： - source-package: 源文件压缩包 - introduction: 说明文件 

        :return: The type of this ShowTemplateFileRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ShowTemplateFileRequest.

        读取文件来源，缺省值为“source-pachage”。  枚举值： - source-package: 源文件压缩包 - introduction: 说明文件 

        :param type: The type of this ShowTemplateFileRequest.
        :type: str
        """
        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowTemplateFileRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
